@@ -15,10 +15,12 @@ class LiveStreamer:
     class for read from a live feed
     """
 
-    def __init__(self, source: str, rate: int):
+    def __init__(self, source: str, rate: int, max_errors: int = 3600):
         self._stream = cv2.VideoCapture(source)
         self._current_time = time.time()
         self._rate = rate
+        self._error_frames = 0
+        self._max_errors = max_errors
 
     @property
     def rate(self) -> int:
@@ -44,6 +46,14 @@ class LiveStreamer:
         """
         return self._stream
 
+    @property
+    def max_errors_allowed(self) -> int:
+        """
+        get number of max errors allowed
+        :return:
+        """
+        return self._max_errors
+
     def __iter__(self):
         return self
 
@@ -51,15 +61,20 @@ class LiveStreamer:
         while self._stream.isOpened():
             ret, frame = self._stream.read()
             if ret:
+                self._error_frames = 0
                 next_time = time.time()
                 elapsed = next_time - self._current_time
                 if elapsed >= 1. / self._rate:
                     self._current_time = next_time
                     return frame, next_time
+            else:
+                self._error_frames += 1
+                if self._error_frames >= self._max_errors:
+                    raise StopIteration("# of error is greater than allowed. stop stream")
             if cv2.waitKey(1) & 0xFF == ord('q'):
                 break
         else:
-            raise StopIteration()
+            raise StopIteration("stream is closed")
 
     def __del__(self):
         self._stream.release()
